@@ -1,12 +1,12 @@
 """
 
 """
-__version__ = "0.1.11.6"
+__version__ = "0.1.13.9"
 
 from .utils.keys import K
 
 from .kit import (
-    F, Q,
+    # F, Q,
     BaseParams, Params,
     Meter, AvgMeter,
 
@@ -20,5 +20,12 @@ from .kit import (
 )
 
 from .contrib.data import collate
+from .contrib.data.collate import CollateBase
+
+from .base_classes import (
+    attr,
+    llist,
+    null, NoneItem
+)
 
 from . import calculate  # initialize schedule attr classes
